@@ -20,6 +20,8 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/Menu.h>
+
 #include <Lum/Button.h>
 #include <Lum/Dialog.h>
 #include <Lum/Panel.h>
@@ -67,17 +69,19 @@ public:
     //gameArea->SetModel(gameArea);
     SetMain(gameArea);
 
-    Lum::MenuDesc *menu=new Lum::MenuDesc();
+  Lum::Def::Menu *menu=Lum::Def::Menu::Create();
 
-    menu
-      ->AddMenuItemSub(_ld(menuProject))
-        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
-    menu
-      ->AddMenuItemSub(_ld(menuEdit))
-        ->AddMenuItemAction(_ld(menuEditSettings),settingsAction);
-    menu
-      ->AddMenuItemSub(_ld(menuHelp))
-        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+  menu
+    ->GroupProject()
+      ->ActionQuit(GetClosedAction())
+    ->End()
+    ->GroupEdit()
+      ->ActionSettings(settingsAction)
+    ->End()
+    ->GroupHelp()
+      //->ActionHelp()
+      ->ActionAbout(aboutAction)
+    ->End();
 
     SetMenu(menu);
 
